package com.taskttl.data.local.dao

import androidx.room.Dao
import androidx.room.Insert
import androidx.room.OnConflictStrategy
import androidx.room.Query
import com.taskttl.data.local.entity.TaskEntity

@Dao
interface TaskDao {

    /**
     * 获取全部
     * @return [List<TaskEntity>]
     */
    @Query("SELECT * FROM tasks")
    suspend fun getAll(): List<TaskEntity>

    /**
     * 获取待办事项由id
     * @param [id] id
     * @return [TaskEntity]
     */
    @Query("SELECT * FROM tasks WHERE id = :id")
    suspend fun getTaskById(id: Int): TaskEntity

    /**
     * 获取未完成待办事项
     * @return [List<TaskEntity>]
     */
    @Query("SELECT * FROM tasks WHERE completed = 0")
    suspend fun getUncompletedTask(): List<TaskEntity>

    /**
     * 获取完成状态待办事项
     * @return [List<TaskEntity>]
     */
    @Query("SELECT * FROM tasks WHERE completed = 1")
    suspend fun getCompletedTask(): List<TaskEntity>

    /**
     * 获取完成状态待办事项
     * @return [List<TaskEntity>]
     */
    @Insert(onConflict = OnConflictStrategy.REPLACE)
    suspend fun addTask(task: TaskEntity): Long

    /**
     * 完成待办事项
     * @param [id] id
     */
    @Query("UPDATE tasks SET completed = 1 WHERE id = :id")
    suspend fun completedTask(id: Int)
}