package com.taskttl.data.repository

import com.taskttl.data.local.dao.TaskDao
import com.taskttl.data.local.entity.TaskEntity
import javax.inject.Inject
import javax.inject.Singleton


@Singleton
class TaskRepository @Inject constructor(
    private val taskDao: TaskDao
) {

    /**
     * 从数据库获取任务
     * @return [List<TaskEntity>]
     */
    suspend fun getAll(): List<TaskEntity> {
        return taskDao.getAll()
    }

    /**
     * 获取待办事项由id
     * @param [id] id
     * @return [TaskEntity]
     */
    suspend fun getTaskById(id: Int): TaskEntity {
        return taskDao.getTaskById(id)
    }

    /**
     * 获取未完成待办事项
     * @return [List<TaskEntity>]
     */
    suspend fun getUncompletedTask(): List<TaskEntity> {
        return taskDao.getUncompletedTask()
    }

    /**
     * 获取完成状态待办事项
     * @return [List<TaskEntity>]
     */
    suspend fun getCompletedTask(): List<TaskEntity> {
        return taskDao.getCompletedTask()
    }

    suspend fun addTask(task: TaskEntity): Long {
        return taskDao.addTask(task)
    }

    suspend fun completedTask(id: Int) {
        taskDao.completedTask(id)
    }
}