package com.taskttl.ui

import android.net.Uri
import androidx.compose.material3.SnackbarHostState
import androidx.compose.runtime.Composable
import androidx.compose.runtime.Stable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.navigation.NavDestination
import androidx.navigation.NavGraph.Companion.findStartDestination
import androidx.navigation.NavHostController
import androidx.navigation.compose.currentBackStackEntryAsState
import androidx.navigation.compose.rememberNavController
import androidx.navigation.navOptions
import com.google.gson.Gson
import com.taskttl.data.local.entity.TaskEntity
import com.taskttl.ui.navigation.MainTopNavItem
import com.taskttl.ui.screen.TASK_DETAIL_ROUTE
import com.taskttl.ui.screen.navigateToAdd
import com.taskttl.ui.screen.navigateToIndex
import com.taskttl.ui.screen.navigateToMy

@Composable
fun rememberAppState(
    navController: NavHostController = rememberNavController(),
    snackBarHostState: SnackbarHostState = remember { SnackbarHostState() }
): TaskTTLAppState {
    return remember(navController) {
        TaskTTLAppState(
            navController = navController,
            snackBarHostState = snackBarHostState
        )
    }
}

@Stable
class TaskTTLAppState(
    val navController: NavHostController,
    val snackBarHostState: SnackbarHostState
) {
    // 默认状态栏图标颜色是深色
    var iconIsLight by mutableStateOf(false)

    val currentDestination: NavDestination?
        @Composable get() = navController.currentBackStackEntryAsState().value?.destination

    fun navigateToContentDetail(taskBean: TaskEntity) {
        navController.navigate(
            "$TASK_DETAIL_ROUTE/${Uri.encode(Gson().toJson(taskBean))}"
        )
    }
}


@Composable
fun rememberMainState(
    navController: NavHostController = rememberNavController(),
    snackBarHostState: SnackbarHostState = remember { SnackbarHostState() }
): MainAppState {
    return remember(navController) {
        MainAppState(
            navController = navController,
            snackBarHostState = snackBarHostState
        )
    }
}

@Stable
class MainAppState(
    val navController: NavHostController,
    val snackBarHostState: SnackbarHostState
) {
    val mainTopLevelDestinations: List<MainTopNavItem> = MainTopNavItem.entries

    val currentDestination: NavDestination?
        @Composable get() = navController.currentBackStackEntryAsState().value?.destination

    fun navigateToMainTopLevelDestination(
        topLevelDestination: MainTopNavItem, changeStatusBarIconMode: (Boolean) -> Unit
    ) {
        val topLevelNavOptions = navOptions {
            popUpTo(navController.graph.findStartDestination().id) {
                saveState = true
            }
            launchSingleTop = true
            restoreState = true
        }

        when (topLevelDestination) {
            MainTopNavItem.INDEX -> {
                navController.navigateToIndex(topLevelNavOptions)
                changeStatusBarIconMode(false)
            }

            MainTopNavItem.ADD -> {
                navController.navigateToAdd(topLevelNavOptions)
                changeStatusBarIconMode(true)
            }

            MainTopNavItem.MY -> {
                navController.navigateToMy(topLevelNavOptions)
                changeStatusBarIconMode(true)
            }
        }
    }
}