package com.taskttl.ui.components

import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.material3.Checkbox
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.alpha
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.hilt.navigation.compose.hiltViewModel
import com.taskttl.data.constant.Constant
import com.taskttl.data.contract.IndexEvent
import com.taskttl.data.local.entity.TaskEntity
import com.taskttl.ui.viewmodel.IndexViewModel

@Composable
fun TaskItem(
    taskEntity: TaskEntity,
//    navController: NavController,
    indexViewModel: IndexViewModel = hiltViewModel()
) {
    Row(
        modifier = Modifier
            .height(80.dp)
            .padding(16.dp),
//            .clickable { navController.navigate("${RouteConfig.EDIT}/${taskEntity.id}") },
        verticalAlignment = Alignment.CenterVertically
    ) {
        Row(
            modifier = Modifier
                .weight(1f)
                .alpha(if (taskEntity.completed) 0.5f else 1f),
            verticalAlignment = Alignment.CenterVertically
        ) {
            Image(
                painter = painterResource(Constant.imageList[taskEntity.category]),
                modifier = Modifier.size(48.dp),
                contentDescription = ""
            )
            Column(
                modifier = Modifier
                    .fillMaxSize()
                    .padding(start = 12.dp),
                verticalArrangement = Arrangement.Center
            ) {
                Text(
                    taskEntity.title,
                    fontSize = 16.sp,
                    fontWeight = FontWeight.Bold
                )
                Text(
                    taskEntity.dueDate.toString(),
                    fontSize = 14.sp,
                    modifier = Modifier.alpha(0.7f)
                )
            }
        }
        Checkbox(
            checked = taskEntity.completed,
            modifier = Modifier.size(24.dp),
            onCheckedChange = {
                indexViewModel.sendEvent(IndexEvent.Completed(taskEntity.id))
            },
        )
    }
}