package com.taskttl.ui.viewmodel

import androidx.lifecycle.viewModelScope
import com.taskttl.data.contract.IndexEffect
import com.taskttl.data.contract.IndexEvent
import com.taskttl.data.contract.IndexState
import com.taskttl.data.repository.TaskRepository
import com.taskttl.utils.Logger
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.launch
import javax.inject.Inject

/**
 * @author Hsy
 * @date 2024/09/06
 * @constructor 创建[IndexViewModel]
 */
@HiltViewModel
class IndexViewModel @Inject constructor(
    private val taskRepository: TaskRepository
) : BaseViewModel<IndexState, IndexEvent, IndexEffect>() {
    override fun initialState(): IndexState = IndexState();

    init {
        getTask()
    }

    private fun getTask() {
        viewModelScope.launch {
            val uncompletedList = taskRepository.getUncompletedTask()
            val comparableList = taskRepository.getCompletedTask()
            Logger.error(uncompletedList.toString())
            Logger.error(comparableList.toString())
            sendEvent(IndexEvent.LoadData(uncompletedList, comparableList))
        }
    }

    override suspend fun handleEvent(event: IndexEvent, state: IndexState): IndexState {
        return when (event) {
            is IndexEvent.LoadData -> {
                return state.copy(
                    isLoading = true,
                    uncompletedList = event.uncompletedList,
                    completedList = event.completedList
                )
            }

            is IndexEvent.Completed -> {
                taskRepository.completedTask(event.id)
                getTask()
                state
            }
        }
    }

}